@@ -83,8 +83,8 @@ DAISIE_MW_loglik_choosepar = function(
   idparsfix,
   pars2,
   datalist,
-  methode = 'lsodes',
-  CS_version = 1,
+  methode = 'odeint::runge_kutta_cash_karp54',
+  CS_version = list(model = 1, function_to_optimize = 'DAISIE'),
   abstolint = 1E-16,
   reltolint = 1E-14,
   distance_type = 'continent',
@@ -382,9 +382,9 @@ DAISIE_MW_ML = function(
   island_ontogeny = NA,
   tol = c(1E-4, 1E-5, 1E-7),
   maxiter = 1000 * round((1.25)^length(idparsopt)),
-  methode = "lsodes",
-  optimmethod = 'subplex',
-  CS_version = 1,
+  methode = "odeint::runge_kutta_cash_karp54",
+  optimmethod = 'simplex',
+  CS_version = list(model = 1, function_to_optimize = 'DAISIE'),
   verbose = 0,
   tolint = c(1E-16, 1E-10),
   distance_type = 'continent',
