@@ -147,10 +147,9 @@ DAISIE_format_CS_full_stt <- function(island_replicates,
     }
     several_islands[[rep]] <- island_list
     if (verbose == TRUE) {
-      message(paste0("Island being formatted: ",
-                  rep,
-                  "/",
-                  length(island_replicates)))
+      message(
+        "Island being formatted: ", rep, "/", length(island_replicates)
+      )
     }
   }
   return(several_islands)
