@@ -53,7 +53,7 @@ DAISIE_make_global <- function(archipelago_list, M, phylo_data, archipelago_data
   global_object <- list()
   for (i in 1:length(archipelago_list)) {
     the_archipelago <- as.character(archipelago_list[i])
-    print(the_archipelago)
+    message(the_archipelago)
     global_object[[i]] <- DAISIE_make_archipelago(the_archipelago, M, phylo_data, archipelago_data)
   }
   return(global_object)
