@@ -86,7 +86,8 @@ DAISIE_sim_core_time_dep <- function(
 
     timeval_and_dt <- calc_next_timeval(
       max_rates = max_rates,
-      timeval = timeval
+      timeval = timeval,
+      total_time = total_time
     )
     timeval <- timeval_and_dt$timeval
 
