@@ -11,7 +11,7 @@ test_that("split-rate model runs silent and
               island_gradient_angle = 0)
             nonoceanic_pars <- c(0, 0)
             hyper_pars <- create_hyper_pars(d = 0, x = 0)
-            expect_silent(
+            testthat::expect_silent(
               DAISIE_sim_core_cr_shift(
                 time = 10,
                 mainland_n = 1,
@@ -35,7 +35,7 @@ test_that("abuse split-rate model with time smaller than shift_times", {
     island_gradient_angle = 0)
   nonoceanic_pars <- c(0, 0)
   hyper_pars <- create_hyper_pars(d = 0, x = 0)
-  expect_error(DAISIE_sim_core_cr_shift(
+  testthat::expect_error(DAISIE_sim_core_cr_shift(
     time = 1,
     mainland_n = 1,
     pars = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
@@ -55,7 +55,7 @@ test_that("abuse split-rate model with gamma = 0", {
     island_gradient_angle = 0)
   nonoceanic_pars <- c(0, 0)
   hyper_pars <- create_hyper_pars(d = 0, x = 0)
-  expect_error(DAISIE_sim_core_cr_shift(
+  testthat::expect_error(DAISIE_sim_core_cr_shift(
     time = 1,
     mainland_n = 1,
     pars = c(1, 1, 1, 0, 1, 1, 1, 1, 1, 1),
