@@ -1,6 +1,6 @@
 test_that("nonontogeny oceanic trait_dependnet island should run silent IW", {
   set.seed(234567890)
-  expect_silent(
+  testthat::expect_silent(
     DAISIE_sim_core_trait_dep(
       time = 10,
       mainland_n = 100,
@@ -28,7 +28,7 @@ test_that("nonontogeny oceanic trait_dependnet island should run silent IW", {
 
 test_that("nonontogeny oceanic trait_dependnet island should run silent CS", {
   set.seed(420)
-  expect_silent(
+  testthat::expect_silent(
     DAISIE_sim_core_trait_dep(
       time = 10,
       mainland_n = 0,
@@ -56,7 +56,7 @@ test_that("nonontogeny oceanic trait_dependnet island should run silent CS", {
 
 test_that("abuse NULL trait pars", {
   set.seed(234567890)
-  expect_error(
+  testthat::expect_error(
     DAISIE_sim_core_trait_dep(
       time = 10,
       mainland_n = 100,
@@ -78,7 +78,7 @@ test_that("abuse NULL trait pars", {
 })
 test_that("abuse NULL trait pars", {
   set.seed(234567890)
-  expect_error(
+  testthat::expect_error(
     DAISIE_sim_core_trait_dep(
       time = 10,
       mainland_n = 100,
