@@ -1,5 +1,5 @@
 test_that("basic use", {
-  expect_true(
+  testthat::expect_true(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -13,7 +13,7 @@ test_that("basic use", {
 
 test_that("check returns FALSE when wrong", {
 
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -23,7 +23,7 @@ test_that("check returns FALSE when wrong", {
     )
   )
 
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = "nonsense",
@@ -33,7 +33,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         clado_rate = 0.1,
@@ -43,7 +43,7 @@ test_that("check returns FALSE when wrong", {
     )
   )
 
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -53,7 +53,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         clado_rate = 0.1,
@@ -63,7 +63,7 @@ test_that("check returns FALSE when wrong", {
     )
   )
 
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -73,7 +73,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -83,7 +83,7 @@ test_that("check returns FALSE when wrong", {
     )
   )
 
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -93,7 +93,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -103,7 +103,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = -1,
@@ -113,7 +113,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -123,7 +123,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -136,7 +136,7 @@ test_that("check returns FALSE when wrong", {
 })
 
 test_that("including two trait states", {
-  expect_true(
+  testthat::expect_true(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -156,7 +156,7 @@ test_that("including two trait states", {
 
 test_that("check returns FALSE when wrong", {
 
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -172,7 +172,7 @@ test_that("check returns FALSE when wrong", {
     )
   )
 
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -189,7 +189,7 @@ test_that("check returns FALSE when wrong", {
     )
   )
 
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -204,7 +204,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -221,7 +221,7 @@ test_that("check returns FALSE when wrong", {
     )
   )
 
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -236,7 +236,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -253,7 +253,7 @@ test_that("check returns FALSE when wrong", {
     )
   )
 
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -268,7 +268,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -278,7 +278,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -294,7 +294,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -309,7 +309,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -325,7 +325,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -340,7 +340,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -356,7 +356,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -372,7 +372,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -388,7 +388,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -404,7 +404,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -420,7 +420,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -436,7 +436,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
@@ -453,7 +453,7 @@ test_that("check returns FALSE when wrong", {
       )
     )
   )
-  expect_false(
+  testthat::expect_false(
     are_rates(
       list(
         immig_rate = 0.1,
