@@ -1,6 +1,6 @@
 test_that("use", {
-  expect_false(is_simulation_outputs("nonsense"))
-  expect_true(is_simulation_outputs(DAISIE_sim_cr(
+  testthat::expect_false(is_simulation_outputs("nonsense"))
+  testthat::expect_true(is_simulation_outputs(DAISIE_sim_cr(
     time = 0.4,
     M = 10,
     pars = c(2, 2, Inf, 0.001, 1),
@@ -8,7 +8,7 @@ test_that("use", {
     plot_sims = FALSE,
     verbose = FALSE)))
 
-  expect_true(is_simulation_outputs(DAISIE_sim_time_dep(
+  testthat::expect_true(is_simulation_outputs(DAISIE_sim_time_dep(
     time = 2,
     M = 500,
     pars = c(0.00001, 1, 0.05, 0.001, 1),
@@ -42,7 +42,7 @@ test_that("abuse is simulation outputs", {
     verbose = FALSE
   )
   names(output[[1]][[1]])[2] <- "nonsense"
-  expect_false(is_simulation_outputs(output))
+  testthat::expect_false(is_simulation_outputs(output))
 })
 
 test_that("abuse is simulation outputs", {
@@ -56,5 +56,5 @@ test_that("abuse is simulation outputs", {
     verbose = FALSE
   )
   names(output[[1]][[1]])[3] <- "nonsense"
-  expect_false(is_simulation_outputs(output))
+  testthat::expect_false(is_simulation_outputs(output))
 })
